from setuptools import setup


setup(
    name='noface',
    version='1.5.0',
    description='a cypher algo by Unproductive',
    packages=['noface'],
    classifiers=['Programming Language :: Python :: 3.11'],
    long_description='''
![STATIC](https://img.shields.io/badge/No_Face-No_Face-gre
) ![STATIC](https://img.shields.io/badge/No_Face-No_Face-blue
) ![STATIC](https://img.shields.io/badge/No_Face-No_Face-black
)



# NOFACE
```
NOFACENOFACENOFACENOFACENOFACE:NOFАCENOFACENOFАCENOFАCENOFАCENOFACENOFACENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFАCENOFACENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFACENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFАCENOFACENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFАCENOFАCENOFАCENOFАCENOFАCENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFАCENOFACENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFАCENOFACENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACENOFACENOFАCENOFACENOFАCENOFACENOFACENOFACENOFАCENOFАCENOFACENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFАCENOFАCENOFАCENOFACENOFАCENOFACENOFАCENOFАCENOFACENOFACENOFАCENOFACENOFАCENOFАCENOFACENOFАCENOFACENOFACENOFACENOFACE
```
-- Слово "Привет", зашифрованное NO FACE

**NOFACE** - Алгоритм симметричного шифрования на Python. <br> <br>
Основная задача NOFACE заключается не в непробиваемой безопасности, а в максимальной нечитаемости содержимого непосвящённым человеком.

## Юседж

```
...
BYTESHIFVALUE = 4
FACE = "NOFACE"
...

```
**В начале кода выставлены две константы - если вы реально хотите, чтобы ваш код был надёжен, рекоммендуем сменить стандартные значения и передать их собеседнику.** <br>
**BYTESHIFTVALUE ДОЛЖНА быть < длины FACE - 1**

<br>

В дополнение, в коде приведена имплементация сдвига бит. Этот вариант безопаснее, но может подхавать некоторые буквы. Используйте, если для вас безопасность важнее точности.

Остальная часть использования должна быть примитивно ясна.


## Встраивание

Укради код

```bash
  git clone https://github.com/Unproductive-Lab/NO-FACE
```

Выкинь в корневую папку проекта и пропиши

```
  from noface.py import *
```

Для шифрования используй

```
    foo = makeface(message)
```

Для расшифровки используй

```
    bar = deface(foo)
```

''',
    long_description_content_type='text/markdown',
    author='Unproductive Lab',
    author_email='107squad107@gmail.com',
    keywords=['noface', 'cypher', 'encoding'],
    url='https://github.com/bgse/hellostackoverflow'
)